@@ -1,6 +1,6 @@
 package Devel::PatchPerl;
 {
-  $Devel::PatchPerl::VERSION = '0.74';
+  $Devel::PatchPerl::VERSION = '0.78';
 }
 
 # ABSTRACT: Patch perl source a la Devel::PPPort's buildperl.pl
@@ -1783,8 +1783,8 @@ END
 sub _patch_589_perlio_c
 {
   _patch(<<'END');
---- a/perlio.c
-+++ b/perlio.c
+--- perlio.c
++++ perlio.c
 @@ -2323,6 +2323,12 @@ PerlIO_init(pTHX)
  {
      /* MUTEX_INIT(&PL_perlio_mutex) is done in PERL_SYS_INIT3(). */
@@ -1803,9 +1803,8 @@ END
 
 qq[patchin'];
 
-
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -1814,7 +1813,7 @@ Devel::PatchPerl - Patch perl source a la Devel::PPPort's buildperl.pl
 
 =head1 VERSION
 
-version 0.74
+version 0.78
 
 =head1 SYNOPSIS
 
@@ -1872,10 +1871,9 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Chris Williams and Marcus Holland-Moritz.
+This software is copyright (c) 2013 by Chris Williams and Marcus Holland-Moritz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
